.. _installation:

Installation
============

The pyghmi Python package can be downloaded and installed with *pip*:

.. code-block:: bash

   $ pip install pyhgmi

Or, if you have virtualenvwrapper installed:

.. code-block:: bash

   $ mkvirtualenv pyghmi
   $ pip install pyghmi
